@@ -11,7 +11,7 @@ with 'Net::GitHub::V3::Query';
 
 sub orgs {
     my ( $self, $user ) = @_;
-    
+
     my $u = $user ? "/users/" . uri_escape($user) . '/orgs' : '/user/orgs';
     return $self->query($u);
 }
@@ -30,8 +30,28 @@ sub close_org {
     return $self->close($u);
 }
 
+sub next_repos {
+    my ( $self, $org ) = @_;
+
+    die "missing org" unless defined $org;
+    my $u = sprintf( "/orgs/%s/repos",  uri_escape($org) );
+    return $self->next($u);
+}
+
+sub close_repos {
+    my ( $self, $org ) = @_;
+
+    die "missing org" unless defined $org;
+    my $u = sprintf( "/orgs/%s/repos",  uri_escape($org) );
+
+    return $self->close($u);
+}
+
 ## build methods on fly
 my %__methods = (
+    ### ------------------------------------------------
+    ### /orgs
+    ### ------------------------------------------------
     org => { url => "/orgs/%s" },
     update_org => { url => "/orgs/%s", method => 'PATCH', args => 1 },
     # Members
@@ -48,8 +68,17 @@ my %__methods = (
     membership => { url => "/orgs/:org/memberships/:username", method => 'GET', v => 2 },
     update_membership => { url => "/orgs/:org/memberships/:username", method => 'PUT', args => 1, v => 2 },
     delete_membership => { url => "/orgs/:org/memberships/:username", method => 'DELETE', check_status => 204, v => 2 },
+
+    # List all repositories for an organisation
+    repos => { url => "/orgs/:org/repos", paginate => 1, v => 2 },
+
     # Org Teams API
     teams => { url => "/orgs/%s/teams", paginate => 1 },
+
+    ### ------------------------------------------------
+    ### /teams
+    ### ------------------------------------------------
+
     team  => { url => "/teams/%s" },
     create_team => { url => "/orgs/%s/teams", method => 'POST', args => 1 },
     update_team => { url => "/teams/%s", method => 'PATCH', args => 1 },
@@ -157,6 +186,22 @@ L<http://developer.github.com/v3/orgs/members/>
 
 =item membership
 
+=item repos
+
+List all repositories for an organization. (can use pagination)
+
+    my $first_100_repos = $org->repos( $organization_name );
+
+Iterate over all repositories for an organization.
+
+    while (my $repo = $org->next_repos( 'Your-Org-Name' ) ) {
+        # do something with $repo
+        say $repo->{name};
+        ...
+    }
+    $org->close_repos( 'Your-Org-Name' );
+
+
 =item update_membership
 
 =item delete_membership
@@ -196,7 +241,7 @@ L<http://developer.github.com/v3/orgs/teams/>
         name => "new team name"
     });
     my $st = $org->delete_team($team_id);
-    
+
 =item team_members
 
 =item is_team_member
